/* Copyright 2015, 2016, Michele Santullo
 * This file is part of "dindexer".
 *
 * "dindexer" is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * "dindexer" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with "dindexer".  If not, see <http://www.gnu.org/licenses/>.
 */

#include "dindexer-machinery/set_listing.hpp"
#include <gtest/gtest.h>
#include <vector>
#include <utility>

//TEST_F for class
TEST(machinery, diriterator) {
	using mchlib::SetListing;
	using mchlib::SetListingView;
	using mchlib::FileRecordData;

	FileRecordData test_data_arr[] = {
		FileRecordData("",0,0,0,true,false),
		FileRecordData("BestAndBest",0,0,1,true,false),
		FileRecordData("BestAndBest/CD1",0,0,2,true,false),
		FileRecordData("BestAndBest/CD1/01 - 紅三四郎.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/02 - アクビ娘.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/03 - 魔法のマコちゃん.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/04 - 心のうた.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/05 - かぐや姫先生のうた.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/06 - けろっこデメタン.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/07 - 緑の陽だまり.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/08 - ジムボタンの歌.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/09 - ぼくらきょうだいてんとう虫.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/10 - シンドバットのぼうけん.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/11 - ペペロの冒険.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/12 - クムクムのうた.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/13 - ほらハックルベリィ·フィン.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/14 - ぐるぐるメダマンおばけだぞ.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/15 - たたかえ!ガ·キーン.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/16 - キャンディ キャンディ.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/17 - あしたがすき.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/18 - ボルテスVの歌.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/19 - 勇気のテーマ.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/20 - 魔女っ子チックル.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/21 - 宇宙魔人ダイケンゴー.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/22 - 燃えろアタック.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/23 - タンゴむりすんな!.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/24 - 花の子ルンルン.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD1/堀江美都子.-.[BEST.And.BEST.Disc1].专辑.(ape).cue",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2",0,0,2,true,false),
		FileRecordData("BestAndBest/CD2/01 - ダルタニアスの歌.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2/02 - 花のなかの花.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2/03 - ハローララベル.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2/04 - 魔法少女ララベル.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2/05 - おもかげ星.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2/06 - 別離.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2/07 - 走れ!ジョリィ.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2/08 - ふたりで半分こ.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2/09 - ハロー!サンディベル.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2/10 - 恋は突然.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2/11 - ぼくたち地球人.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2/12 - ゆかいな大脱走.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2/13 - Dream of you.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2/14 - あなたに真実一路.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2/15 - ふりむけばDanger!.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2/16 - 青空っていいな.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2/17 - ひみつのアッコちゃん.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2/18 - DON’T YOU···?.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2/19 - グローイング·アップ.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2/20 - キミの風.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2/21 - 太陽を追いかけて.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2/22 - 思い出の鏡.flac",0,0,3,false,false),
		FileRecordData("BestAndBest/CD2/堀江美都子.-.[BEST.And.BEST.Disc2].专辑.(ape).cue",0,0,3,false,false),
		FileRecordData("BestAndBest/CD.txt",0,0,2,false,false),
		FileRecordData("BestAndBest/Scans",0,0,2,true,false),
		FileRecordData("BestAndBest/Scans/01.jpg",0,0,3,false,false),
		FileRecordData("BestAndBest/Scans/02.jpg",0,0,3,false,false),
		FileRecordData("BestAndBest/Scans/03.jpg",0,0,3,false,false),
		FileRecordData("BestAndBest/Scans/04.jpg",0,0,3,false,false),
		FileRecordData("City Hunter",0,0,1,true,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.1",0,0,2,true,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.1/01 - City Hunter - Ai yo Kienaide.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.1/02 - Cool City.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.1/03 - Mr. Private Eye.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.1/04 - Midnight Lightning.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.1/05 - Blue Air Message.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.1/06 - Get Wild.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.1/07 - The Ballad Of Silver Bullet.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.1/08 - What's Goin' On.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.1/09 - Blood On The Moon.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.1/10 - Give Me Your Love Tonight.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.1/cityhunter-ost-back.jpg",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.1/cityhunter-ost-frot.jpg",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.2",0,0,2,true,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.2/(01) - Want Your Love.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.2/(02) - Just a Hunter.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.2/(03) - Go Go Heaven.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.2/(04) - Fire with Fire.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.2/(05) - Never go Away.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.2/(06) - Owari no nai Katamuki.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.2/(07) - The Shining of Cat's Eye.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.2/(08) - Footsteps.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.2/(09) - Paradise Alley.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.2/(10) - Suna no Castle no Casanova.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 1 - Original Animation Soundtrack Vol.2/cover (small).jpg",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - #2 BayCity Wars, #3 Plot of $1,000,000",0,0,2,true,false),
		FileRecordData("City Hunter/City Hunter - #2 BayCity Wars, #3 Plot of $1,000,000/01. Rock My Love - Yoko Oginome.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - #2 BayCity Wars, #3 Plot of $1,000,000/02. Night Moves - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - #2 BayCity Wars, #3 Plot of $1,000,000/03. DeathTrap - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - #2 BayCity Wars, #3 Plot of $1,000,000/04. Kanojo no Omoi - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - #2 BayCity Wars, #3 Plot of $1,000,000/05. Woman in the Dark - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - #2 BayCity Wars, #3 Plot of $1,000,000/06. Easy-Going Guy - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - #2 BayCity Wars, #3 Plot of $1,000,000/07. Take Me Back - Yoko Yamauchi.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - #2 BayCity Wars, #3 Plot of $1,000,000/08. Baycity Battle - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - #2 BayCity Wars, #3 Plot of $1,000,000/09. More More Shiawase - Yoko Oginome.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - #2 BayCity Wars, #3 Plot of $1,000,000/10. Never Say Goodbye - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - #2 BayCity Wars, #3 Plot of $1,000,000/cover (small).jpg",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.1",0,0,2,true,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.1/01 - CHANCE.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.1/02 - ANGEL NIGHT.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.1/03 - DOMINO TARGET (INSTRUMENTAL).mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.1/04 - YOUR SECRETS.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.1/05 - CITY HEAT.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.1/06 - FANTASTIC SPLASH (INSTRUMENTAL).mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.1/07 - EARTH.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.1/08 - NO NO NO.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.1/09 - LADY IN THE DARK (INSTRUMENTAL).mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.1/10 - SUPER GIRL.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.1/11 - LONELY LULLABY.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.1/cityhunter2-ost1-back.jpg",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.1/cityhunter2-ost1-front.jpg",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.2",0,0,2,true,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.2/01. Jennifer Cihi - Name of the Game.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.2/02. Fence Of Defence - Sara.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.2/03. Kamiya Akira - Gimme Shock.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.2/04. Instrumental - Crime and passion.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.2/05. Jennifer Cihi - Without You.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.2/06. Kitadai Momoko - Party Down.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.2/07. Ikura Kazue - Show Light Shower.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.2/08. Instrumental - Holy Night Rhapsody.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.2/09. Kitadai Momoko - Escape.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.2/10. Kamiya Akira, Ikura Kazue - Machi-jyu sophisticate.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.2/11. Instrumental - Sweet twilight.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.2/City Hunter 2 - OST 2 - Back.JPG",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 2 - Original Animation Soundtrack Vol.2/City Hunter 2 - OST 2 - Front.jpg",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 3 - Original Animation Soundtrack",0,0,2,true,false),
		FileRecordData("City Hunter/City Hunter 3 - Original Animation Soundtrack/City Hunter Season 03 OST - 01 - Running to Horizon - Tetsuya Komuro.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 3 - Original Animation Soundtrack/City Hunter Season 03 OST - 02 - A Love No One Can Change - Akira Kamiya.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 3 - Original Animation Soundtrack/City Hunter Season 03 OST - 03 - Forever In My Heart - Kristen Steinhauer.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 3 - Original Animation Soundtrack/City Hunter Season 03 OST - 04 - Just like Magic - RED MONSTER.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 3 - Original Animation Soundtrack/City Hunter Season 03 OST - 05 - Shy ni Sexy - Mari Nishizono.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 3 - Original Animation Soundtrack/City Hunter Season 03 OST - 06 - The Pressure - ANIMA.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 3 - Original Animation Soundtrack/City Hunter Season 03 OST - 07 - Candy - Ruriko Kuboh.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 3 - Original Animation Soundtrack/City Hunter Season 03 OST - 08 - Requiem (BGM).mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 3 - Original Animation Soundtrack/City Hunter Season 03 OST - 09 - Midnight Rain - ANIMA.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 3 - Original Animation Soundtrack/City Hunter Season 03 OST - 10 - Atsuku Naretara - Kiyomi Suzuki.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter 3 - Original Animation Soundtrack/cover (small).jpg",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter '91 - City Hunter '91 - Original Animation Soundtrack",0,0,2,true,false),
		FileRecordData("City Hunter/City Hunter '91 - City Hunter '91 - Original Animation Soundtrack/01 - Down Town Game.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter '91 - City Hunter '91 - Original Animation Soundtrack/02 - May Be Rich .mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter '91 - City Hunter '91 - Original Animation Soundtrack/03 - Kiss Me Again.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter '91 - City Hunter '91 - Original Animation Soundtrack/04 - Spring Breeze.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter '91 - City Hunter '91 - Original Animation Soundtrack/05 - You Never Know My Heart.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter '91 - City Hunter '91 - Original Animation Soundtrack/06 - Tropical Fish Scenery.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter '91 - City Hunter '91 - Original Animation Soundtrack/07 - Bay in the Night.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter '91 - City Hunter '91 - Original Animation Soundtrack/08 - Sometimes Get My Love.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter '91 - City Hunter '91 - Original Animation Soundtrack/09 - Hold Me Slowly.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter '91 - City Hunter '91 - Original Animation Soundtrack/10 - Smile & Smile.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter '91 - City Hunter '91 - Original Animation Soundtrack/11 - Asphalt Moon.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter '91 - City Hunter '91 - Original Animation Soundtrack/cover (small).jpg",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - A Magnum of love's destination",0,0,2,true,false),
		FileRecordData("City Hunter/City Hunter - A Magnum of love's destination/01. Shuumatsu no Soldier  - Mika Kaneko.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - A Magnum of love's destination/02. Asphalt Dandy  - Tatsumi Yano.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - A Magnum of love's destination/03. One and Only  - Tatsumi Yano.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - A Magnum of love's destination/04. Troop In Midnight  - Tatsumi Yano.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - A Magnum of love's destination/05. Only In My Dreams  - Yurie Koboku.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - A Magnum of love's destination/06. Get Out!  - Tatsumi Yano.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - A Magnum of love's destination/07. Love Games  - Yurie Koboku.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - A Magnum of love's destination/08. Nina  - Tatsumi Yano.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - A Magnum of love's destination/09. Wish You're Here  - Tatsumi Yano.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - A Magnum of love's destination/10. Juurokuya - Mariko Takahashi.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - A Magnum of love's destination/City Hunter - Magnum of love's destination - Back.jpg",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - A Magnum of love's destination/City Hunter - Magnum of love's destination - Front.jpg",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Best Collections",0,0,2,true,false),
		FileRecordData("City Hunter/City Hunter - Best Collections/01-Soldier In The Night.MP3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Best Collections/02-JUUROKUYA.MP3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Best Collections/03-Down Town Game.MP3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Best Collections/04-City Hunter- Ai yo serenaide.MP3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Best Collections/05-Mr.Private Eye.MP3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Best Collections/06-Get Wild.MP3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Best Collections/07-Change.MP3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Best Collections/08-Angel Night.MP3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Best Collections/09-Give Me Your Love Tonight.MP3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Best Collections/10-Earth.MP3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Best Collections/11-Running To Horizon.MP3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Best Collections/12-Forever In My Heart.MP3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Best Collections/13-Midnight Rain.MP3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Best Collections/14-Atsuku Naretara.MP3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Best Collections/15-Hold Me Tight.MP3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Best Collections/Cover (small).jpg",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol. 1",0,0,2,true,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol. 1/01 . [Scene 1 Rival] Angel Night - PSY-S.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol. 1/02 . What's Goin' On - Kahoru Kohiruimaki.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol. 1/03 . Go Go Heaven - Yoshiyuki Oshawa.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol. 1/04 . No No No - Ryo Ogura.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol. 1/05 . Footsteps - Momoko Kitadai.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol. 1/06 . Earth - PSY-S.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol. 1/07 . [Scene 2 Old Friend] Super Girl - Yasuyuki Okamura.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol. 1/08 . Still Love Her - TM NETWORK.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol. 1/09 . City Hunter (Ai Yo Kienaide) - Kahoru Kohiruimaki.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol. 1/10 . [Scene 3 Tempter] Mr. Private Eye - Yuko Otaki.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol. 1/11 . Owari no nai Katamuki - Yoshiyuki Oshawa.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol. 1/12 . Sara - Fence Of Defense.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol. 1/13 . Give Me Your Love Tonight - Kiyomi Suzuki.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol. 1/14 . Party Down - Momoko Kitadai.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol. 1/15 . [Scene 4 Best Partner] Get Wild - TM NETWORK.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol. 1/back_chdm.jpg",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol. 1/front_chdm.jpg",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2",0,0,2,true,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/cover (small).jpg",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 1 - Vocal Master",0,0,3,true,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 1 - Vocal Master/01 - Hold me Tight.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 1 - Vocal Master/02 - Scene N°1 - Cat's Eye + Lonely Lullaby.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 1 - Vocal Master/03 - Without You.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 1 - Vocal Master/04 - Suno no Castle no Cassanova.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 1 - Vocal Master/05 - City Heat.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 1 - Vocal Master/06 - Scene N°2 - Duel I + Cool City.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 1 - Vocal Master/07 - Scene N°3 - Duel II + Snow Light Shower.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 1 - Vocal Master/08 - Scene N°4 - Duel III + Atsuku Naretara.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 1 - Vocal Master/09 - Name of the Game.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 1 - Vocal Master/10 - Blue Air Message.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 1 - Vocal Master/11 - Machi-jyu Sophisticate.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 1 - Vocal Master/12 - Make Up Tonight.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 1 - Vocal Master/13 - Scene N°5 - Battle + Running to horizon.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 1 - Vocal Master/14 - Your Secrets.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 1 - Vocal Master/15 - Chance.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 2 - Instrumental Master",0,0,3,true,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 2 - Instrumental Master/01 - 大谷 幸プロジェクト-DOMINO TARGET.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 2 - Instrumental Master/02 - 矢野立美プロジェクト-PARADISE ALLEY.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 2 - Instrumental Master/03 - 国吉良一プロジェクト-THE BALLAD OF SILVER BULLET.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 2 - Instrumental Master/04 - 矢野立美プロジェクト-CRIME AND PASSION.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 2 - Instrumental Master/05 - 矢野立美プロジェクト-JUST A HUNTER.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 2 - Instrumental Master/06 - 国吉良一プロジェクト-BLOOD ON THE MOON.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 2 - Instrumental Master/07 - 矢野立美プロジェクト-FANTASTIC SPLASH.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 2 - Instrumental Master/08 - 大谷 幸プロジェクト-HOLY NIGHT RHAPSODY.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 2 - Instrumental Master/09 - 矢野立美プロジェクト-FIRE WITH FIRE.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 2 - Instrumental Master/10 - 国吉良一プロジェクト-MIDNIGHT LIGHTNING.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 2 - Instrumental Master/11 - 矢野立美プロジェクト-THE SHINING OF CAT'S EYE.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 2 - Instrumental Master/12 - 大谷 幸プロジェクト-SWEET TWILIGHT.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 2 - Instrumental Master/13 - 矢野立美プロジェクトWITH北代桃子-WANT YOUR LOVE.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 2 - Instrumental Master/14 - 大谷 幸プロジェクト-LADY IN THE DARK.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter - Dramatic Master Vol.2/Disc 2 - Instrumental Master/15 - 矢野立美プロジェクト-FEREWELL MY HUNTER.mp3",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter Special",0,0,2,true,false),
		FileRecordData("City Hunter/City Hunter Special/01-AudioTrack 01.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/02-AudioTrack 02.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/03-AudioTrack 03.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/04-AudioTrack 04.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/05-AudioTrack 05.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/06-AudioTrack 06.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/07-AudioTrack 07.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/08-AudioTrack 08.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/09-AudioTrack 09.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/10-AudioTrack 10.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/11-AudioTrack 11.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/12-AudioTrack 12.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/13-AudioTrack 13.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/14-AudioTrack 14.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/15-AudioTrack 15.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/16-AudioTrack 16.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/17-AudioTrack 17.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/18-AudioTrack 18.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/19-AudioTrack 19.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/20-AudioTrack 20.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/21-AudioTrack 21.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/22-AudioTrack 22.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/23-AudioTrack 23.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/24-AudioTrack 24.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/25-AudioTrack 25.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special/covers",0,0,3,true,false),
		FileRecordData("City Hunter/City Hunter Special/covers/City Hunter Special Kinkyo namachukai Kyouakuhan !! Ryo Saeba no Saigo OST-back.jpg",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter Special/covers/City Hunter Special Kinkyo namachukai Kyouakuhan !! Ryo Saeba no Saigo OST-front.jpg",0,0,4,false,false),
		FileRecordData("City Hunter/City Hunter Special - Good-Bye My Sweet Heart",0,0,2,true,false),
		FileRecordData("City Hunter/City Hunter Special - Good-Bye My Sweet Heart/01. Ride On the Night - Humming Bird.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Good-Bye My Sweet Heart/02. Open Your Eyes - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Good-Bye My Sweet Heart/03. Professor Mutoh - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Good-Bye My Sweet Heart/04. Joshiryo - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Good-Bye My Sweet Heart/05. Hurry Up! - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Good-Bye My Sweet Heart/06. Good-Bye My... - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Good-Bye My Sweet Heart/07. Dead Or Alive - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Good-Bye My Sweet Heart/08. My Dear - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Good-Bye My Sweet Heart/09. Warlike - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Good-Bye My Sweet Heart/10. Black Roses - Dawn Marie Moore.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Good-Bye My Sweet Heart/11. Feel So Blue - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Good-Bye My Sweet Heart/12. Burst Out Diving - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Good-Bye My Sweet Heart/13. The Trap - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Good-Bye My Sweet Heart/14. Chase On The Battlefield - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Good-Bye My Sweet Heart/15. Memory Of Black Roses - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Good-Bye My Sweet Heart/16. Force Pollution - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Good-Bye My Sweet Heart/17. Critical Moment - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Good-Bye My Sweet Heart/18. Emi - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Good-Bye My Sweet Heart/19. Get Wild (City Hunter Special '97 Version) - Naho.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Good-Bye My Sweet Heart/City Hunter Special - Good-Bye My Sweet Heart OST - Back.jpg",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Good-Bye My Sweet Heart/City Hunter Special - Good-Bye My Sweet Heart OST - Front.jpg",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage",0,0,2,true,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/01. Prologue 1 - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/02. Illusion City (TV Size) - Sex Machinegun.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/03. Prologue 2 - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/04. Yubiwa No Theme - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/05. TV Music - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/06. Mokkori - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/07. Ryo & Kaori - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/08. Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/09. Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/10. Escape From Darkness - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/11. Mad Dock No Theme - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/12. Suspense - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/13. Battle - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/14. Hado Boirudo - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/15. Ai No Theme - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/16. Danger Zone - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/17. Sayaka No Theme - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/18. Sayuri No Theme 1 - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/19. Sayuri No Theme 2 - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/20. Jack No Theme 1 - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/21. Jack No Theme 2 - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/22. Jack No Theme 3 - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/23. Magnum Fire (TV Size) - Sex Machinegun.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/24. End Of The Story - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/25. Epilogue - Instrumental.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/City Hunter  - Special '99 OST - Back.jpg",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter Special - Live on Stage/City Hunter  - Special '99 OST - Front.jpg",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - The Secret Service",0,0,2,true,false),
		FileRecordData("City Hunter/City Hunter - The Secret Service/01. Konta - Otherwise.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - The Secret Service/02. Instrumental - Hunter In The City.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - The Secret Service/03. Instrumental - Kyôhaku.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - The Secret Service/04. Instrumental - Guinamo No Himitsu.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - The Secret Service/05. Brian Peck - We Can Make It.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - The Secret Service/06. Instrumental - Unmei No Itu.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - The Secret Service/07. Instrumental - Utsukushii Shiki Irai Hito.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - The Secret Service/08. Instrumental - Chase ! Chase ! Chase !.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - The Secret Service/09. Yûsuke Nakamura - If You Can't See.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - The Secret Service/10. Instrumental - Battle Cruising.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - The Secret Service/11. Instrumental - Tatta Hitotsu No Omoide.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - The Secret Service/12. Instrumental - Bonds.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - The Secret Service/13. Instrumental - Ikaruri No Jûdan.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - The Secret Service/14. Instrumental - Easy Life Again.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - The Secret Service/15. Anne-Louise - Woman.mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - The Secret Service/16. Konta - Otherwise (TV version).mp3",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - The Secret Service/City Hunter - Service Secret OST - Back.jpg",0,0,3,false,false),
		FileRecordData("City Hunter/City Hunter - The Secret Service/City Hunter - Service Secret OST - Front.jpg",0,0,3,false,false),
		FileRecordData("Cowboy Bebop - Tank - The Best",0,0,1,true,false),
		FileRecordData("Cowboy Bebop - Tank - The Best/01 - Tank! (TV stretch).mp3",0,0,2,false,false),
		FileRecordData("Cowboy Bebop - Tank - The Best/02 - WHAT PLANET IS THIS..mp3",0,0,2,false,false),
		FileRecordData("Cowboy Bebop - Tank - The Best/03 - COSMIC DARE (PRETTY WITH A PISTOL).mp3",0,0,2,false,false),
		FileRecordData("Cowboy Bebop - Tank - The Best/04 - DIAMONDS.mp3",0,0,2,false,false),
		FileRecordData("Cowboy Bebop - Tank - The Best/05 - Don't bother none (TV edit).mp3",0,0,2,false,false),
		FileRecordData("Cowboy Bebop - Tank - The Best/06 - PIANO BLACK.mp3",0,0,2,false,false),
		FileRecordData("Cowboy Bebop - Tank - The Best/07 - MUSHROOM HUNTING.mp3",0,0,2,false,false),
		FileRecordData("Cowboy Bebop - Tank - The Best/08 - No Reply.mp3",0,0,2,false,false),
		FileRecordData("Cowboy Bebop - Tank - The Best/09 - BLUE.mp3",0,0,2,false,false),
		FileRecordData("Cowboy Bebop - Tank - The Best/10 - EINSTEIN GROOVIN'.mp3",0,0,2,false,false),
		FileRecordData("Cowboy Bebop - Tank - The Best/11 - PEARLS.mp3",0,0,2,false,false),
		FileRecordData("Cowboy Bebop - Tank - The Best/12 - Gotta knock a little harder.mp3",0,0,2,false,false),
		FileRecordData("Escaflowne",0,0,1,true,false),
		FileRecordData("Escaflowne/cd1 - Over the sky",0,0,2,true,false),
		FileRecordData("Escaflowne/cd1 - Over the sky/01 - Yakusoku wa iranai.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd1 - Over the sky/02 - Flying Dragon.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd1 - Over the sky/03 - Dance of Curse.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd1 - Over the sky/04 - Murder.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd1 - Over the sky/05 - Escaflowne.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd1 - Over the sky/06 - Angel.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd1 - Over the sky/07 - Cubic.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd1 - Over the sky/08 - Romance.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd1 - Over the sky/09 - Ne Zu Mi.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd1 - Over the sky/10 - Wings.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd1 - Over the sky/11 - Gloria.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd1 - Over the sky/12 - Eyes.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd1 - Over the sky/13 - Empty the pocket.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd1 - Over the sky/14 - White Dove.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd1 - Over the sky/15 - Mystic Eyes.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd1 - Over the sky/16 - Deja Blue.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd2",0,0,2,true,false),
		FileRecordData("Escaflowne/cd2/01 - The vision of Escaflowne.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd2/02 - Fanelia.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd2/03 - Ask the owl.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd2/04 - Charm.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd2/05 - Country man.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd2/06 - A mole man.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd2/07 - Cradle song.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd2/08 - Machine soldier.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd2/09 - Shadow of doubt.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd2/10 - A far cry.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd2/11 - Market place.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd2/12 - Medicine eater.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd2/13 - Godds drunk.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd2/14 - Cats delicacy.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd2/15 - Love.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd2/16 - Hitomi theme.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd2/17 - If you.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd3",0,0,2,true,false),
		FileRecordData("Escaflowne/cd3/01 - Short notice.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd3/02 - Arcadia.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd3/03 - Epistle.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd3/04 - Farewell.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd3/05 - Aoi Hitomi.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd3/06 - Perfect world.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd3/07 - I recommend instincts.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd3/08 - Scrappy.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd3/09 - Shrilly.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd3/10 - Revenge.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd3/11 - Illusion.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd3/12 - Blaze.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd3/13 - Fatal.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd3/14 - Hikari no naka e.mp3",0,0,3,false,false),
		FileRecordData("Escaflowne/cd3/15 - Again.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core",0,0,1,true,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1",0,0,2,true,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/101 Fragments of Memories -D.M.W-.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/102 Theme of CRISIS CORE ''Successor''.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/103 Mission Start.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/104 First Mission (from FFVII ''Opening ~ Bombing Mission'').mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/105 The Mako City.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/106 Patriots on a Moonlit Night.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/107 Encounter.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/108 Theme of CRISIS CORE ''Dreams and Pride''.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/109 Last Order - Crisis Mix (from ''LAST ORDER FFVII'').mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/110 Burden of Truth.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/111 Wandering on a Sunny Afternoon.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/112 Conflict.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/113 Controlling the Iron Beast.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/114 Theme of CRISIS CORE ''Under the Apple Tree''.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/115 The Summoned (from FFVII ''Those Who Fight Further'').mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/116 The Burdened.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/117 On the Verge of the Assault (from FFVII ''Those Who Fight'').mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/118 The Clandestine Dark Suits (from FFVII ''Turk's Theme'').mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/119 The Skyscraper of Iron and Steel (from ''LAST ORDER FFVII'').mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/120 Combat.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/121 Theme of CRISIS CORE ''Scars of Friendship''.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/122 A Flower Blooming in the Slums (from FFVII ''Aerith's Theme'').mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/123 Sky-Blue Eyes.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/124 Theme of CRISIS CORE ''With Pride''.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/125 Melody of Agony.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/126 March on the Frontier (from ''LAST ORDER FFVII'').mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/127 A Moment of Courtesy.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/128 A Beating Black Wing.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/129 Theme of CRISIS CORE ''Truth Behind the Project''.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/130 The Face of Lost Pride.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 1/131 Why (CCFFVII Mix).mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2",0,0,2,true,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/201 Town Where the Sunlight Doesn't Reach.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/202 A Changing Situation.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/203 The Mako-Controlling Organization (from FFVII ''Shinra Company'').mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/204 Theme of CRISIS CORE ''To a New Post''.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/205 A Closed Off Village (from FFVII ''Anxious Heart'').mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/206 Farewell Melody.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/207 The Gloomy Mansion.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/208 A Momentary Rest.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/209 Prelude of Ruin.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/210 The World's Enemy (from FFVII ''One-Winged Angel'').mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/211 Night of Seclusion.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/212 Duty and Friendship.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/213 Theme of CRISIS CORE ''Chaotic Battlefield''.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/214 Wilderness of Desertion.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/215 Melody of Resolution.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/216 Moonlight Wandering (from ''LAST ORDER FFVII'').mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/217 An Ancient Hymn Sung by the Water.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/218 Howl of the Gathered.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/219 Those Who Accept the Protection of the Stars.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/220 SOLDIER Battle.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/221 The Price of Freedom.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/222 Why.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/223 Fulfilled Desire.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy Crisis Core/Disk 2/224 to be continued (from FFVII ''Opening ~ Bombing Mission'').mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII",0,0,1,true,false),
		FileRecordData("Final Fantasy XIII/CD1",0,0,2,true,false),
		FileRecordData("Final Fantasy XIII/CD1/01 - Prelude to FINAL FANTASY XIII.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD1/02 - FINAL FANTASY XIII - The Promise.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD1/03 - The Thirteenth Day.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD1/04 - Defiers of Fate.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD1/05 - Saber's Edge.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD1/06 - The Hanging Edge.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD1/07 - Those For the Purge.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD1/08 - The Warpath Home.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD1/09 - The Pulse Fal'Cie.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD1/10 - Face It Later.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD1/11 - Snow's Theme.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD1/12 - The Vestige.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD1/13 - Ragnarok.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD1/14 - In the Sky That Night.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD1/15 - Promised Eternity.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD1/16 - Eternal Love (Short Version).mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD1/17 - Lake Bresha.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD1/18 - The Pulse L'Cie.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD1/19 - Eidolons.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD2",0,0,2,true,false),
		FileRecordData("Final Fantasy XIII/CD2/01 - Blinded By Light.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD2/02 - Glory's Fanfare.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD2/03 - Battle Results.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD2/04 - A Brief Respite.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD2/05 - Cavalry Theme.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD2/06 - Escape.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD2/07 - Crash Landing.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD2/08 - Daddy's Got the Blues.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD2/09 - The Vile Peaks.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD2/10 - Lightning's Theme.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD2/11 - Sazh's Theme.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD2/12 - March of the Dreadnoughts.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD2/13 - The Gapra Whitewood.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD2/14 - Tension in the Air.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD2/15 - Forever Fugitives.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD2/16 - The Sunleth Waterscape.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD2/17 - Lost Hope.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD2/18 - To Hunt L'Cie.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD2/19 - No Way to Live.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD2/20 - Sustained by Hate.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD2/21 - The Pulse L'Cie.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD2/22 - Serah's Theme.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD3",0,0,2,true,false),
		FileRecordData("Final Fantasy XIII/CD3/01 - Can't Catch a Break.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD3/02 - PSICOM.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD3/03 - Hope's Theme.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD3/04 - This Is Your Home.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD3/05 - Atonement.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD3/06 - Vanille's Theme.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD3/07 - The Final Stage.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD3/08 - The Pompa Sancta.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD3/09 - Nautilus.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD3/10 - Chocobos of Cocoon - Chasing Dreams.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD3/11 - Feast of Betrayal.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD3/12 - Eidolons on Parade.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD3/13 - Test of the L'Cie.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD3/14 - All the World Against Us.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD3/15 - Game Over.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD3/16 - Primarch Dysley.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD3/17 - Fighting Fate.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD3/18 - Separate Paths.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD3/19 - Setting You Free.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD3/20 - Desperate Struggle.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD3/21 - Mysteries Abound.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD3/22 - Will to Fight.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD4",0,0,2,true,false),
		FileRecordData("Final Fantasy XIII/CD4/01 - Fang's Theme.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD4/02 - Terra Incognita.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD4/03 - The Archylte Steppe.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD4/04 - Chocobos of Pulse.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD4/05 - The Yaschas Massif.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD4/06 - Memories of Happier Days.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD4/07 - Sulyya Springs.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD4/08 - Taejin's Tower.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD4/09 - Dust to Dust.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD4/10 - The Road Home.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD4/11 - Start Your Engines.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD4/12 - Eden Under Siege.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD4/13 - The Cradle Will Fall.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD4/14 - Born Anew.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD4/15 - Sinful Hope.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD4/16 - Fabula Nova Crystallis.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD4/17 - FINAL FANTASY XIII - Miracles.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD4/18 - Focus.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD4/19 - Nascent Requiem.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD4/20 - Determination.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD4/21 - Kimi ga Irukara (Long Version).mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD4/22 - Ending Credits.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD5",0,0,2,true,false),
		FileRecordData("Final Fantasy XIII/CD5/01 - Chapter 01.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD5/02 - Chapter 02.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD5/03 - Chapter 03.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD5/04 - Chapter 04.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD5/05 - Chapter 05.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD5/06 - Chapter 06.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/CD5/07 - Chapter 07.mp3",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers",0,0,2,true,false),
		FileRecordData("Final Fantasy XIII/Covers/Back In.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Back.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Book Back.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Book Front.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Book Inlay.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 10.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 11.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 12.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 13.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 14.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 15.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 16.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 17.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 18.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 19.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 1.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 20.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 21.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 22.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 23.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 24.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 25.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 26.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 27.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 28.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 29.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 2.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 30.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 31.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 32.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 33.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 3.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 4.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 5.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 6.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 7.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 8.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Booklet 9.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/CD1.JPG",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/CD2.JPG",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/CD3.JPG",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/CD4.JPG",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/CD5.JPG",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Digi Back.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Digi Front.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Digi Inside.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Digipack 1.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Digipack 2.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Digipack 3.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Digipack 4.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Digipack 5.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Front Box.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Front.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/OBI.JPG",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Vinyl Back.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Covers/Vinyl Front.jpg",0,0,3,false,false),
		FileRecordData("Final Fantasy XIII/Front Box.jpg",0,0,2,false,false),
		FileRecordData("Last Exile",0,0,1,true,false),
		FileRecordData("Last Exile/cd1",0,0,2,true,false),
		FileRecordData("Last Exile/cd1/01 - Okino Shuntaro Cloud Age Symphony.ogg",0,0,3,false,false),
		FileRecordData("Last Exile/cd1/02 - Dolce Triade A Morning in Norkia.ogg",0,0,3,false,false),
		FileRecordData("Last Exile/cd1/03 - Dolce Triade Workin on the Cloud.ogg",0,0,3,false,false),
		FileRecordData("Last Exile/cd1/04 - Dolce Triade To the Race.ogg",0,0,3,false,false),
		FileRecordData("Last Exile/cd1/05 - Hitomi Prayer for Love.ogg",0,0,3,false,false),
		FileRecordData("Last Exile/cd1/06 - Dolce Triade Brave Willing.ogg",0,0,3,false,false),
		FileRecordData("Last Exile/cd1/07 - Dolce Triade Cover Stories.ogg",0,0,3,false,false),
		FileRecordData("Last Exile/cd1/08 - Dolce Triade Flyin to Fly.ogg",0,0,3,false,false),
		FileRecordData("Last Exile/cd1/09 - Hitomi Requiem in the Air.ogg",0,0,3,false,false),
		FileRecordData("Last Exile/cd1/10 - Dolce Triade Hello Kitty Girl.ogg",0,0,3,false,false),
		FileRecordData("Last Exile/cd1/11 - Dolce Triade Chivalry Spirits.ogg",0,0,3,false,false),
		FileRecordData("Last Exile/cd1/12 - Dolce Triade Advances.ogg",0,0,3,false,false),
		FileRecordData("Last Exile/cd1/13 - Dolce Triade Naval Affair.ogg",0,0,3,false,false),
		FileRecordData("Last Exile/cd1/14 - Dolce Triade All is Over.ogg",0,0,3,false,false),
		FileRecordData("Last Exile/cd1/15 - Okino Shuntaro skywriting.ogg",0,0,3,false,false),
		FileRecordData("Last Exile/cd1/16 - Dolce Triade Silverna.ogg",0,0,3,false,false),
		FileRecordData("Last Exile/cd1/17 - Dolce Triade Vanishing Point.ogg",0,0,3,false,false),
		FileRecordData("Last Exile/cd1/18 - Dolce Triade Complicated Decision.ogg",0,0,3,false,false),
		FileRecordData("Last Exile/cd1/19 - Hitomi Over the Sky.ogg",0,0,3,false,false),
		FileRecordData("Last Exile/cd2",0,0,2,true,false),
		FileRecordData("Last Exile/cd2/01 Dolce Triade - Road To The Light.mp3",0,0,3,false,false),
		FileRecordData("Last Exile/cd2/02 OKINO,SHUNTARO - Head In The Clouds.mp3",0,0,3,false,false),
		FileRecordData("Last Exile/cd2/03 Dolce Triade - Fleet Of Littleships.mp3",0,0,3,false,false),
		FileRecordData("Last Exile/cd2/04 Dolce Triade - Heavy Cocoon.mp3",0,0,3,false,false),
		FileRecordData("Last Exile/cd2/05 Dolce Triade - Ground Stream.mp3",0,0,3,false,false),
		FileRecordData("Last Exile/cd2/06 Dolce Triade - A Stimulant.mp3",0,0,3,false,false),
		FileRecordData("Last Exile/cd2/07 hitomi - Rays Of Hope.mp3",0,0,3,false,false),
		FileRecordData("Last Exile/cd2/08 Dolce Triade - Beautiful Fields.mp3",0,0,3,false,false),
		FileRecordData("Last Exile/cd2/09 Dolce Triade - Coronation.mp3",0,0,3,false,false),
		FileRecordData("Last Exile/cd2/10 Dolce Triade - Lost Friend.mp3",0,0,3,false,false),
		FileRecordData("Last Exile/cd2/11 Dolce Triade - Princess, Sophia.mp3",0,0,3,false,false),
		FileRecordData("Last Exile/cd2/12 OKINO,SHUNTARO - I Can See A Heart.mp3",0,0,3,false,false),
		FileRecordData("Last Exile/cd2/13 Dolce Triade - Malicious Queen.mp3",0,0,3,false,false),
		FileRecordData("Last Exile/cd2/14 Dolce Triade - Ceremonius Play.mp3",0,0,3,false,false),
		FileRecordData("Last Exile/cd2/15 Dolce Triade - Counterattack.mp3",0,0,3,false,false),
		FileRecordData("Last Exile/cd2/16 Dolce Triade - Make Advantage.mp3",0,0,3,false,false),
		FileRecordData("Last Exile/cd2/17 Dolce Triade - Dreams Of Fathers.mp3",0,0,3,false,false),
		FileRecordData("Last Exile/cd2/18 Dolce Triade - Lastexile.mp3",0,0,3,false,false),
		FileRecordData("Last Exile/cd2/19 hitomi - Over The Sky ＜Angel Feather Version＞.mp3",0,0,3,false,false),
		FileRecordData("Last Exile/cd2/20 hitomi - A New World Has Come.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok",0,0,1,true,false),
		FileRecordData("Ragnarok/CD1",0,0,2,true,false),
		FileRecordData("Ragnarok/CD1/02 - Gambler of highway.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/03 - Peaceful Forest.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/04 - I miss you.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/05 - Tread on the ground.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/06 - Risk your life.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/07 - Wind of Tragedy.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/08 - Theme of Prontera.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/09 - Great honor.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/10 - Divine Grace.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/11 - Theme of Morroc.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/12 - Streamside.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/13 - Theme of Geffen.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/14 - Theme of Payon.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/15 - Theme of Alberta.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/16 - Labyrinth.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/17 - Treasure Hunter.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/18 - Time up.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/19 - Under the ground.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/20 - Ancient groover.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/21 - Through the tower.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/22 - Backattack.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/23 - Travel.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/24 - Desert.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD1/25 - Plateau.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2",0,0,2,true,false),
		FileRecordData("Ragnarok/CD2/01 - Everlasting Wanderers.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/02 - Dreamers Dream.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/03 - Youre in ruins.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/04 - Be Nicen Easy.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/05 - One Step Closer.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/06 - Brassy Road.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/07 - Yuna Song.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/08 - Pampas Upas.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/09 - TeMPoison.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/10 - Nano East.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/11 - TeMPorsche.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/12 - Hamatan.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/13 - Theme of Al de Baran.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/14 - Fear.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/15 - Cursen Pain.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/16 - Morning Gloomy.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/17 - TeMP it Up.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/18 - Dont Piss me Off.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/19 - An Ant-lions Pit.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/20 - Welcome MrHwang.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/21 - Help Yourself.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/22 - Watery Grave.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/23 - Out of Curiosity.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/24 - Believe in myself.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/CD2/25 - Ready.ogg",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData",0,0,2,true,false),
		FileRecordData("Ragnarok/GameData/01.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/02.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/03.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/04.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/05.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/06.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/07.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/08.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/09.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/10.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/11.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/12.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/13.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/14.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/15.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/16.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/17.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/18.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/19.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/20.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/21.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/22.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/23.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/24.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/25.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/26.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/27.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/28.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/29.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/30.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/31.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/33.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/34.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/35.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/36.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/37.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/38.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/39.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/40.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/41.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/42.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/43.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/44.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/45.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/46.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/47.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/48.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/49.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/50.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/51.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/52.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/53.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/54.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/55.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/56.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/57.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/58.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/59.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/60.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/61.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/62.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/63.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/64.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/65.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/66.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/67.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/68.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/69.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/70.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/71.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/72.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/73.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/74.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/75.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/76.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/77.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/78.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/79.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/80.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/81.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/82.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/83.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/84.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/85.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/86.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/87.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/GameData/88.mp3",0,0,3,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation",0,0,2,true,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/Ragnarok the Animation OP ED Single - We are the Stars [Yamazaki Maimi]",0,0,3,true,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/Ragnarok the Animation OP ED Single - We are the Stars [Yamazaki Maimi]/01 - We are the Stars.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/Ragnarok the Animation OP ED Single - We are the Stars [Yamazaki Maimi]/02 - Alive.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/Ragnarok the Animation OP ED Single - We are the Stars [Yamazaki Maimi]/03 - We are the Stars [Karaoke].mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/Ragnarok the Animation OP ED Single - We are the Stars [Yamazaki Maimi]/04 - Alive [Karaoke].mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs",0,0,3,true,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/01 - Theme or RAGNAROK THE ANIMATION.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/02 - We are the Stars (TV size).mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/03 - Monogatari no Hajimari.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/04 - Nonki na Ichidou.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/05 - Kafra Kyouiku Kouza.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/06 - Ashiki Taidou.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/07 - Sabishiki Machi.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/08 - Fuon na Hadou.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/09 - Maya no Komoriuta.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/10 - Ma-chan neru.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/11 - Shock!.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/12 - Ochita Eiyuu.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/13 - Yokisenu Dekigoto.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/14 - Kage Semaru.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/15 - Sentou Kaishi.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/16 - Mukau tokoro Teki nashi!.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/17 - Tatakai no Ato.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/18 - Yodonda Kehai.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/19 - Mitometakunai.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/20 - We are the Stars (BMG arrange).mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/21 - Otenba.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/22 - Gikochinai Kankei.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/23 - Chotto dake ne!.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/24 - Endless Sorrow.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/25 - Ikoku no Chi.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/26 - Oomoke!.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/27 - Odore Odore!.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/28 - Samayoeru Tamashii.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/29 - Shinobi Yoru Ihen.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/30 - Tsugi wa Docchi da.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/31 - Tomadoi nagara.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/32 - Haruka naru Omoi.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/33 - With ~Chiisana Chikara~.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/34 - Aishuu no Houyou.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/35 - Kikiippatsu.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/36 - Jiken Hassei.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/37 - Kyoufu.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/38 - Akuma no Shiro.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/39 - Taosu beki Kabe.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/40 - Welcome Back.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/41 - Yuusha Tanjou.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/42 - Kamigami no Tasogare.mp3",0,0,4,false,false),
		FileRecordData("Ragnarok/Ragnarok The Animation/RAGNAROK THE ANIMATION Original Soundtrack and Character Songs/43 - Alive (TV size).mp3",0,0,4,false,false),
		FileRecordData("Tekkaman",0,0,1,true,false),
		FileRecordData("Tekkaman/01 - Uchuu Amakakeru Kishidan - Tekkaman no Uta (TV Size).mp3",0,0,2,false,false),
		FileRecordData("Tekkaman/02 - Hoshi Kara Kita Otoko.mp3",0,0,2,false,false),
		FileRecordData("Tekkaman/03 - Hiromi to Mutan.mp3",0,0,2,false,false),
		FileRecordData("Tekkaman/04 - Chikyuu Ryakudatsu Shirei.mp3",0,0,2,false,false),
		FileRecordData("Tekkaman/05 - Gekitou no Tekkaman.mp3",0,0,2,false,false),
		FileRecordData("Tekkaman/06 - Minamijuujisei.mp3",0,0,2,false,false),
		FileRecordData("Tekkaman/07 - Yameru Chikyuu.mp3",0,0,2,false,false),
		FileRecordData("Tekkaman/08 - Voltekka.mp3",0,0,2,false,false),
		FileRecordData("Tekkaman/09 - Harukanaru Sanno-Sei.mp3",0,0,2,false,false),
		FileRecordData("Tekkaman/10 - Weekend.mp3",0,0,2,false,false),
		FileRecordData("Tekkaman/11 - Waldaster Trap.mp3",0,0,2,false,false),
		FileRecordData("Tekkaman/12 - Taiyou no Yuusha.mp3",0,0,2,false,false),
		FileRecordData("Tekkaman/13 - Leap, Tek Set!.mp3",0,0,2,false,false),
		FileRecordData("Tekkaman/14 - Saigo no Tekkaman.mp3",0,0,2,false,false),
		FileRecordData("Tekkaman/15 - Space Knights no Uta (TV Size).mp3",0,0,2,false,false),
		FileRecordData("Tekkaman LP",0,0,1,true,false),
		FileRecordData("Tekkaman LP/01 - Ichirou Mizuki - Tekkaman no uta.mp3",0,0,2,false,false),
		FileRecordData("Tekkaman LP/02 - Ichirou Mizuki - Space Knight no uta.mp3",0,0,2,false,false),
		FileRecordData("Vultus 5",0,0,1,true,false),
		FileRecordData("Vultus 5/voltes_v_ending_full_minus_one_karaoke.mp3",0,0,2,false,false),
		FileRecordData("Vultus 5/voltes_v_ending_full.mp3",0,0,2,false,false),
		FileRecordData("Vultus 5/voltes_v_ending_tv.mp3",0,0,2,false,false),
		FileRecordData("Vultus 5/voltes_v_opening_full_minus_one_karaoke.mp3",0,0,2,false,false),
		FileRecordData("Vultus 5/voltes_v_opening_full.mp3",0,0,2,false,false),
		FileRecordData("Vultus 5/voltes_v_opening_full_reperformed.mp3",0,0,2,false,false),
		FileRecordData("Vultus 5/voltes_v_opening_horie_mitsuko_live.mp3",0,0,2,false,false),
		FileRecordData("Vultus 5/voltes_v_opening_tv.mp3",0,0,2,false,false),
		FileRecordData("Vultus 5/テレビオリジナルＢＧＭコレクション 超電磁マシーン ボルテスV",0,0,2,true,false),
		FileRecordData("Vultus 5/テレビオリジナルＢＧＭコレクション 超電磁マシーン ボルテスV/01_ボルテスVの歌 (TV用唄入り).mp3",0,0,3,false,false),
		FileRecordData("Vultus 5/テレビオリジナルＢＧＭコレクション 超電磁マシーン ボルテスV/02_侵略の魔手 〜ボアザン星辺境征軍地球に来襲す〜.mp3",0,0,3,false,false),
		FileRecordData("Vultus 5/テレビオリジナルＢＧＭコレクション 超電磁マシーン ボルテスV/03_ボルテス・雄姿の出現 〜地球の命運を双肩に賭けて〜.mp3",0,0,3,false,false),
		FileRecordData("Vultus 5/テレビオリジナルＢＧＭコレクション 超電磁マシーン ボルテスV/04_若き英雄たち 〜正義に燃える青春の血潮〜.mp3",0,0,3,false,false),
		FileRecordData("Vultus 5/テレビオリジナルＢＧＭコレクション 超電磁マシーン ボルテスV/05_ブリッジ・コレクション.mp3",0,0,3,false,false),
		FileRecordData("Vultus 5/テレビオリジナルＢＧＭコレクション 超電磁マシーン ボルテスV/06_ボルテス・死闘の戦歴 〜壮絶なる超電磁の攻防戦〜.mp3",0,0,3,false,false),
		FileRecordData("Vultus 5/テレビオリジナルＢＧＭコレクション 超電磁マシーン ボルテスV/07_剛兄弟出生の秘密 〜ラ・ゴール如何に宿命と闘いしか〜.mp3",0,0,3,false,false),
		FileRecordData("Vultus 5/テレビオリジナルＢＧＭコレクション 超電磁マシーン ボルテスV/08_大宇宙への出発 〜悲劇のボアザン星解放へ向かって〜.mp3",0,0,3,false,false),
		FileRecordData("Vultus 5/テレビオリジナルＢＧＭコレクション 超電磁マシーン ボルテスV/09_悲劇の終幕 〜貴公子ハイネル紅蓮の炎に消ゆ〜.mp3",0,0,3,false,false),
		FileRecordData("Vultus 5/テレビオリジナルＢＧＭコレクション 超電磁マシーン ボルテスV/10_父をもとめて (TV用唄入り).mp3",0,0,3,false,false)
	};

	std::vector<FileRecordData> test_data(std::make_move_iterator(std::begin(test_data_arr)), std::make_move_iterator(std::end(test_data_arr)));
	SetListing lst(std::move(test_data));

	auto i = lst.begin();
	EXPECT_EQ("BestAndBest", i->abs_path);

	{
		auto view = SetListingView(i);
		auto i2 = view.cbegin();
		EXPECT_EQ("BestAndBest/CD1", i2->abs_path);

		++i2;
		EXPECT_EQ("BestAndBest/CD2", i2->abs_path);
	}

	++i;
	EXPECT_EQ("City Hunter", i->abs_path);
}
